// ============================================================================
// Project:	Deductive Database
// Filename:	syn.h
// Purpose:	Syntax Error Messages
// Last Change:	06.10.2016
// Language:	C++
// EMail:	brass@informatik.uni-halle.de
// WWW:		http://www.informatik.uni-halle.de/~brass/
// Address:	Feldschloesschen 15, D-06120 Halle (Saale), GERMANY
// Copyright:	(c) 2015-2016 by Stefan Brass
// License:	See file "LICENSE" for copying conditions.
// Note:	There is no warranty at all - this code may contain bugs.
// ============================================================================


//=============================================================================
// Include File Frame:
//=============================================================================

#ifndef	SYN_INCLUDED
#define SYN_INCLUDED

//=============================================================================
// Used Types and Macros:
//=============================================================================

#ifndef VER_INCLUDED
#include "ver.h"
#endif

#ifndef STR_INCLUDED
#include "str.h"
#endif

#ifndef CHECK_INCLUDED
#include "check.h"
#endif

//=============================================================================
// Exported Types:
//=============================================================================

//-----------------------------------------------------------------------------
// syn_t: Syntax error messages.
//-----------------------------------------------------------------------------

typedef enum {
	SYN_PRED_EXPECTED,
	SYN_UNKNOWN_PRED,
	SYN_LPAREN_EXPECTED,
	SYN_RPAREN_EXPECTED,
	SYN_COMMA_EXPECTED,
	SYN_FULLSTOP_EXPECTED,
	SYN_ARG_MUST_BE_STR,
	SYN_ARG_MUST_BE_ATOM,
	SYN_ARG_MUST_BE_ATOM_OR_STR,
	SYN_ARG_MUST_BE_INT,
	SYN_ARG_CANNOT_BE_NEGATIVE,
	SYN_INVALID_ARG_TYPE,
	SYN_ILLEGAL_CHAR,
	SYN_MISSINGQ,
	SYN_NOSPACE,
	SYN_INT_OVERFLOW,
	SYN_BAD_ESCAPE_SEQ
} syn_t;

//=============================================================================
// Exported Functions:
//=============================================================================

//-----------------------------------------------------------------------------
// syn_valid: Is the parameter a valid element of the enumeration type?
//-----------------------------------------------------------------------------

#ifdef	VER_DEBUG
bool	syn_valid(syn_t syn);
#endif

//-----------------------------------------------------------------------------
// syn_text: Text of the error message.
//-----------------------------------------------------------------------------

str_t	syn_text(syn_t syn);

//=============================================================================
// End of File:
//=============================================================================

#endif

